@@ -1,8 +1,10 @@
 __all__ = ["AlarmQueryResult", "AlarmQueryResultImpl"]
 
-from typing import Any
+from typing import Any, Iterator, List
 
-from com.inductiveautomation.ignition.common.alarming import PyAlarmEvent
+from com.inductiveautomation.ignition.common import Dataset
+from com.inductiveautomation.ignition.common.alarming import AlarmEvent, PyAlarmEvent
+from java.lang import String
 
 
 class AlarmQueryResult(object):
@@ -15,12 +17,15 @@ class AlarmQueryResult(object):
     """
 
     def getAssociatedDate(self, uuid):
+        # type: (String) -> Dataset
         raise NotImplementedError
 
     def getDataSet(self):
+        # type: () -> Dataset
         raise NotImplementedError
 
     def getEvent(self, uuid):
+        # type: (String) -> AlarmEvent
         raise NotImplementedError
 
 
@@ -30,13 +35,22 @@ class AlarmQueryResultImpl(AlarmQueryResult):
         pass
 
     def __iter__(self):
+        # type: () -> Iterator[PyAlarmEvent]
         yield PyAlarmEvent()
 
+    @staticmethod
+    def buildFrom(results):
+        # type: (List[AlarmQueryResult]) -> AlarmQueryResult
+        pass
+
     def getAssociatedDate(self, uuid):
+        # type: (String) -> Dataset
         pass
 
     def getDataSet(self):
+        # type: () -> Dataset
         pass
 
     def getEvent(self, uuid):
+        # type: (String) -> AlarmEvent
         pass
