@@ -8,12 +8,14 @@ __all__ = [
     "Frame",
     "Graphics",
     "Image",
+    "Point",
     "Toolkit",
     "Window",
 ]
 
 from typing import Any, Optional
 
+from java.awt.geom import Point2D
 from java.lang import Object, String
 from java.util import EventObject
 
@@ -56,7 +58,7 @@ class Component(Object):
         height,  # type: int
     ):
         # type: (...) -> bool
-        pass
+        return True
 
 
 class Container(Component):
@@ -79,6 +81,39 @@ class Image(Object):
         pass
 
 
+class Point(Point2D):
+    x = 0
+    y = 0
+
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        pass
+
+    def getLocation(self):
+        # type: () -> Point
+        pass
+
+    def getX(self):
+        # type: () -> float
+        pass
+
+    def getY(self):
+        # type: () -> float
+        pass
+
+    def move(self, x, y):
+        # type: (int, int) -> None
+        pass
+
+    def setLocation(self, *args):
+        # type: (*Any) -> None
+        pass
+
+    def translate(self, dx, dy):
+        # type: (int, int) -> None
+        pass
+
+
 class Toolkit(Object):
     def __init__(self):
         # type: () -> None
