@@ -57,6 +57,7 @@ class Watchable(object):
 
 class FileStore(Object):
     def getAttribute(self, attribute):
+        # type: (String) -> Object
         raise NotImplementedError
 
     def getBlockSize(self):
@@ -154,12 +155,12 @@ class Files(Object):
     @staticmethod
     def deleteIfExists(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def exists(path, *options):
         # type: (Path, *LinkOption) -> bool
-        pass
+        return True
 
     @staticmethod
     def find(start, maxDepth, matcher, *options):
@@ -199,42 +200,42 @@ class Files(Object):
     @staticmethod
     def isDirectory(path, *options):
         # type: (Path, *LinkOption) -> bool
-        pass
+        return True
 
     @staticmethod
     def isExecutable(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def isHidden(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def isReadable(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def isRegularFile(path, *options):
         # type: (Path, *LinkOption) -> bool
-        pass
+        return True
 
     @staticmethod
     def isSameFile(path, path2):
         # type: (Path, Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def isSymbolicLink(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def isWritable(path):
         # type: (Path) -> bool
-        pass
+        return True
 
     @staticmethod
     def lines(path, cs=None):
@@ -284,7 +285,7 @@ class Files(Object):
     @staticmethod
     def notExists(path, *options):
         # type: (Path, *LinkOption) -> bool
-        pass
+        return True
 
     @staticmethod
     def probeContentType(path):
@@ -378,11 +379,11 @@ class Path(Watchable):
 
     def endsWith(self, other):
         # type: (Union[Object, Path, String]) -> bool
-        pass
+        return True
 
     def equals(self, other):
         # type: (Object) -> bool
-        pass
+        return True
 
     def getFileName(self):
         # type: () -> Path
@@ -410,7 +411,7 @@ class Path(Watchable):
 
     def isAbsolute(self):
         # type: () -> bool
-        pass
+        return True
 
     def iterator(self):
         # type: () -> Iterator[Path]
@@ -443,7 +444,7 @@ class Path(Watchable):
 
     def startsWith(self, other):
         # type: (Path) -> bool
-        pass
+        return True
 
     def subpath(self, beginIndex, endIndex):
         # type: (int, int) -> Path
