@@ -8,11 +8,13 @@ from __future__ import print_function
 
 __all__ = [
     "Calendar",
+    "Collection",
     "Comparator",
     "Currency",
     "Date",
     "EventObject",
     "Iterator",
+    "ListIterator",
     "Locale",
     "Spliterator",
     "TimeZone",
@@ -27,6 +29,8 @@ from java.time import Instant, ZoneId
 from java.util.function import (
     Consumer,
     Function,
+    Predicate,
+    Supplier,
     ToDoubleFunction,
     ToIntFunction,
     ToLongFunction,
@@ -36,6 +40,80 @@ E = TypeVar("E")
 T = TypeVar("T")
 
 
+class Collection(object):
+    def add(self, e):
+        # type: (E) -> bool
+        raise NotImplementedError
+
+    def addAll(self, c):
+        # type: (Collection) -> bool
+        raise NotImplementedError
+
+    def clear(self):
+        # type: () -> None
+        raise NotImplementedError
+
+    def contains(self, o):
+        # type: (Object) -> bool
+        raise NotImplementedError
+
+    def containsAll(self, c):
+        # type: (Collection) -> bool
+        raise NotImplementedError
+
+    def equals(self, o):
+        # type: (Object) -> bool
+        raise NotImplementedError
+
+    def hashCode(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def isEmpty(self):
+        # type: () -> bool
+        raise NotImplementedError
+
+    def iterator(self):
+        # type: () -> Iterator
+        raise NotImplementedError
+
+    def parallelStream(self):
+        # type: () -> Stream
+        raise NotImplementedError
+
+    def remove(self, o):
+        # type: (Object) -> bool
+        raise NotImplementedError
+
+    def removeAll(self, c):
+        # type: (Collection) -> bool
+        raise NotImplementedError
+
+    def removeIf(self, filter):
+        # type: (Predicate) -> bool
+        raise NotImplementedError
+
+    def retainAll(self, v):
+        # type: (Collection) -> bool
+        raise NotImplementedError
+
+    def size(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def spliterator(self):
+        # type: () -> Spliterator
+        raise NotImplementedError
+
+    def stream(self):
+        # type: () -> Stream
+        raise NotImplementedError
+
+    def toArray(self, arg=None):
+        # type: (Optional[Any]) -> List[Object]
+        raise NotImplementedError
+
+
 class Comparator(object):
     def compare(self, o1, o2):
         # type: (T, T) -> int
@@ -121,7 +199,41 @@ class Iterator(object):
 
     def remove(self):
         # type: () -> bool
-        pass
+        return True
+
+
+class ListIterator(Iterator):
+    def add(self, e):
+        # type: (E) -> None
+        raise NotImplementedError
+
+    def hasNext(self):
+        # type: () -> bool
+        raise NotImplementedError
+
+    def hasPrevious(self):
+        # type: () -> bool
+        raise NotImplementedError
+
+    def next(self):
+        # type: () -> E
+        raise NotImplementedError
+
+    def nextIndex(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def previous(self):
+        # type: () -> E
+        raise NotImplementedError
+
+    def previousIndex(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def set(self, e):
+        # type: (E) -> None
+        raise NotImplementedError
 
 
 class Spliterator(object):
@@ -156,7 +268,7 @@ class Spliterator(object):
 
     def hasCharacteristics(self, characteristics):
         # type: (int) -> bool
-        pass
+        return True
 
     def tryAdvance(self, action):
         # type: (Consumer) -> bool
@@ -167,6 +279,56 @@ class Spliterator(object):
         raise NotImplementedError
 
 
+class Stream(object):
+    @staticmethod
+    def builder():
+        # type: () -> Builder
+        pass
+
+    @staticmethod
+    def concat(a, b):
+        # type: (Stream, Stream) -> Stream
+        pass
+
+    @staticmethod
+    def empty():
+        # type: () -> Stream
+        pass
+
+    @staticmethod
+    def generate(s):
+        # type: (Supplier) -> Stream
+        pass
+
+    @staticmethod
+    def iterate(*args):
+        # type: (*Any) -> Stream
+        pass
+
+    @staticmethod
+    def of(*args):
+        # type: (*T) -> Stream
+        pass
+
+    @staticmethod
+    def ofNullable(t):
+        # type: (T) -> Stream
+        pass
+
+    class Builder(Consumer):
+        def accept(self, t):
+            # type: (T) -> None
+            raise NotImplementedError
+
+        def add(self, t):
+            # type: (T) -> Stream.Builder
+            pass
+
+        def build(self):
+            # type: () -> Stream
+            raise NotImplementedError
+
+
 class Calendar(Object):
     ALL_STYLES = None  # type: int
     AM = None  # type: int
@@ -225,11 +387,11 @@ class Calendar(Object):
 
     def after(self, when):
         # type: (Object) -> bool
-        pass
+        return True
 
     def before(self, when):
         # type: (Object) -> bool
-        pass
+        return True
 
     def clear(self, field=None):
         # type: (Optional[int]) -> None
@@ -303,15 +465,15 @@ class Calendar(Object):
 
     def isLenient(self):
         # type: () -> bool
-        pass
+        return True
 
     def isSet(self, field):
         # type: (int) -> bool
-        pass
+        return True
 
     def isWeekDateSUpported(self):
         # type: () -> bool
-        pass
+        return True
 
     def roll(self, field, amount):
         # type: (int, int) -> None
@@ -397,11 +559,11 @@ class Date(Object):
 
     def after(self, when):
         # type: (Date) -> bool
-        pass
+        return True
 
     def before(self, when):
         # type: (Date) -> bool
-        pass
+        return True
 
     def compareTo(self, anotherDate):
         # type: (Date) -> int
@@ -456,10 +618,10 @@ class Locale(Object):
         self.country = country
         self.variant = variant
 
-    def __repr__(self):
+    def __repr__(self):  # type: ignore[no-untyped-def]
         return "{!r}".format(self.__str__())
 
-    def __str__(self):
+    def __str__(self):  # type: ignore[no-untyped-def]
         ret = self.language
         if self.country:
             ret += "_{}".format(self.country)
@@ -618,7 +780,7 @@ class TimeZone(Object):
 
     def hasSameRules(self, other):
         # type: (TimeZone) -> bool
-        pass
+        return True
 
     def isDaylightTime(self, date):
         # type: (Date) -> bool
@@ -626,7 +788,7 @@ class TimeZone(Object):
 
     def observesDaylightTime(self):
         # type: () -> bool
-        pass
+        return True
 
     @staticmethod
     def setDefault(zone):
