@@ -8,7 +8,8 @@ __all__ = [
 
 from typing import Any
 
-from java.lang import IllegalArgumentException, String
+from java.lang import IllegalArgumentException, Number
+from org.apache.commons.math3.exception.util import ExceptionContext
 
 
 class MathIllegalArgumentException(IllegalArgumentException):
@@ -18,12 +19,13 @@ class MathIllegalArgumentException(IllegalArgumentException):
     semantics of the standard IllegalArgumentException.
     """
 
-    def __init__(self, pattern, *args):
-        # type: (String, *Any) -> None
-        print(pattern, args)
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        print(args)
         super(MathIllegalArgumentException, self).__init__()
 
     def getContext(self):
+        # type: () -> ExceptionContext
         pass
 
 
@@ -38,6 +40,7 @@ class MathIllegalNumberException(MathIllegalArgumentException):
     INTEGER_ZERO = 0
 
     def getArgument(self):
+        # type: () -> Number
         pass
 
 
@@ -46,7 +49,8 @@ class DimensionMismatchException(MathIllegalNumberException):
 
     def __init__(self, *args):
         # type: (*Any) -> None
-        super(DimensionMismatchException, self).__init__("", *args)
+        super(DimensionMismatchException, self).__init__(*args)
 
     def getDimension(self):
+        # type: () -> int
         pass
